@@ -2,7 +2,7 @@
  *
  *  BlueZ - Bluetooth protocol stack for Linux
  *
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -60,6 +60,7 @@
 #include "storage.h"
 #include "sdpd.h"
 #include "glib-helper.h"
+#include "proxy.h"
 
 #define SERIAL_PORT_NAME	"spp"
 #define SERIAL_PORT_UUID	"00001101-0000-1000-8000-00805F9B34FB"
@@ -1032,7 +1033,8 @@ static void parse_proxy(char *key, char *value, void *data)
 	char uuid128[MAX_LEN_UUID_STR], tmp[3];
 	char *pvalue;
 	proxy_type_t type;
-	int ch, opts, pos;
+	unsigned int pos;
+	int ch, opts;
 	struct termios ti;
 	uint8_t *pti;
 
